#! /usr/bin/env python
import os
from os.path import expandvars
from I3Tray import *

import sys,getopt

load("libicetray")
load("libdataclasses")
load("libphys-services")
load("libsimclasses")
load("libdataio")
load("libicepick")
load("libmmc-icetray")
load("libsim-prod")
load("libsim-services")
load("libcoordinate-service")
load("libbrutus")
load("libromeo-interface")
load("libDOMsimulator")
load("libDOMcalibrator")
load("libweighting-module")
load("libDomTools")

gcdfile = "/net/local/icecube/i3tools/RHEL4-x86_64/test-data/sim/GCD.i3.gz"
infile = "/net/usr/mina/temp/mmc/1TeV/mmc000003.i3.gz"
outfile = "hit000003.i3.gz"
outrootfile = "tmp.root"
outrootfile2 = "tmp2.root"
runnum = 1

if len(sys.argv) > 1:
    infile = sys.argv[1]
if len(sys.argv) > 2:
    outfile = sys.argv[2]
if len(sys.argv) > 3:
    outrootfile = sys.argv[3]
if len(sys.argv) > 4:
    outrootfile2 = sys.argv[4]
if len(sys.argv) > 5:
    runnum = sys.argv[5]
                        


photonics = expandvars("$I3_BUILD")

tray = I3Tray()

tray.AddService("I3ReaderServiceFactory","reader")(
    ("filenameList", [gcdfile, infile])
    )

stringsToUse = "21,29,30,38,39,40,49,50,59,58,67,66,74,73,65,72,78,48,57,47,46,56"
stationsToUse = "21,29,30,38,39,40,47,48,49,50,57,58,59,66,67,74,46,56,65,73,72,78,77,71,64,55"

tray.AddService("I3GeometrySelectorServiceFactory","geo-selector")(
    ("StringsToUse",stringsToUse),
    ("StationsToUse",stationsToUse),
    ("ShiftX",-310.),
    ("ShiftY",-189.),
    ("GeoSelectorName","IC22-IT26-Geo")
    )

tray.AddService("I3SPRNGRandomServiceFactory","sprngrandom")(
    ("NStreams",500),
    ("Seed",1234),
    ("StreamNum",runnum),
    )

tray.AddService("I3PSInterfaceFactory","PSInterface")(
    ("Interface","Photonics"),
    ("TablesDirectory",photonics),
    ("PhotonicsLevel1DriverFile","level1_table.list"),
    ("PhotonicsLevel2DriverFile","level2_table.list"),
    ("PhotonicsTableSelection",1) # cascade only
    )



tray.AddModule("I3Muxer","muxer")(
    ("GeometryService","IC22-IT26-Geo")
    )

tray.AddModule("I3IcePickModule<I3SkipNEventFilter>", "skip")(
    ("discardEvents", True),
    ("SkipNevents", 1),
#    ("NeventStopick", 5)
    )

tray.AddModule("Dump","dump")

tray.AddModule("I3HitConstructorModuleEHE","hit-constructor-ehe")(
    ("MaxMCHits", 500000),
    ("MinEnergy", 100.)
    )

tray.AddModule("I3RomeoInterfaceModule","romeo")(
    ("SkipPhotoCathodeSimulator", False),
    ("StorePMTPulses", False),                     # skip to store ceCubePMTPulse
    ("RomeoOutputTimeResolution", 10.*I3Units.ns), # must same as MCHitBinSize of I3MCHitCompressor
    ("RomeoVerboseLevel", 0)                       # verbose level, 0=silence to 5=trace
    )

tray.AddModule("I3DOMsimulator","domsimulator")(
    ("SimulatePedestalDroop",True)
    )

tray.AddModule("I3DOMLaunchCleaning","launchcleaning")(
    ("InIceInput","InIceRawData"),
    ("IceTopInput","IceTopRawData"),
    ("InIceOutput","CleanInIceRawData"),
    ("IceTopOutput","CleanIceTopRawData"),
    ("FirstLaunchCleaning",True),
    ("CleanedKeys",[OMKey(29,59),#Dead/problem list
                    OMKey(29,60),
                    OMKey(30,23),
                    OMKey(30,60),
                    OMKey(38,59),
                    OMKey(39,22),
                    OMKey(50,36),
                    OMKey(74,9),
                    OMKey(40,51),
                    OMKey(40,52),
                    OMKey(46,49),
                    OMKey(46,50),
                    OMKey(46,53),
                    OMKey(46,54),
                    OMKey(46,55),
                    OMKey(46,56),
                    OMKey(47,55),
                    OMKey(47,56),
                    OMKey(56,57),
                    OMKey(56,58),
                    OMKey(72,37),
                    OMKey(72,38),
                    OMKey(39,8), #Dark Noise mode only DOMS
                    OMKey(50,58),
                    OMKey(72,33),
                    OMKey(72,34),
                    OMKey(72,35),
                    OMKey(72,36),
                    OMKey(72,43),])
                    )

tray.AddModule("I3DOMcalibrator","domcalibrator")(
    ("InputRawDataName","CleanInIceRawData"),
    ("CalibrationMode",1),
    ("CorrectPedestalDroopDualTau", False)
    )

tray.AddModule("I3MMCTreeMaker","treemaker")(
    ("outTreeName",            "MMCTree"),
    ("outFileName",            outrootfile),
    ("inPrimaryCRTreeName",    "I3MCTree"),
    ("inMMCTrackListName",     "MMCTrackList"),
    ("inMCHitSeriesName",      "MCHitSeriesMap"),
    ("inDOMLaunchName",        "CleanInIceRawData"),
    
    ("doPulseTree",            False),
    ("inAtwdPortiaName",       "ATWDPortiaPulse"),
    ("inFadcPortiaName",       "FADCPortiaPulse"),
    
    ("doMCHitTree",            False),
    ("McHitCompressionOption", True),
    
    ("doFirstguessTree",       False),
    ("inFirstguessName",       "OpheliaFirstGuess"),
    )

tray.AddModule("I3Portia","pulse")(
    ("DataReadoutName",             "CleanInIceRawData"),
    ("ATWDPulseSeriesName",         "ATWDPulseSeries"),
    ("ATWDPortiaPulseName",         "ATWDPortiaPulse"),
    ("ATWDWaveformName",            "CalibratedATWD"),
    ("ATWDBaseLineOption",          "eheoptimized"),
    ("FADCBaseLineOption",          "eheoptimized"),
    ("ATWDThresholdCharge",         0.0*I3Units.C),
    ("ATWDLEThresholdAmplitude",    0.5*I3Units.mV),
    
    ("UseFADC", True),
    ("FADCPulseSeriesName",         "FADCPulseSeries"),
    ("FADCPortiaPulseName",         "FADCPortiaPulse"),
    ("FADCWaveformName",            "CalibratedFADC"),
    ("FADCThresholdCharge",         0.0*I3Units.C),
    ("FADCLEThresholdAmplitude",    0.5*I3Units.mV),
    ("MakeBestPulseSeries",         False),
    ("BestPortiaPulseName",         "BestPortiaPulse"),
    #("PMTGain",                     1.0e7)
    )

tray.AddModule("I3EHEFirstGuess", "reco")(
    ("MinimumNumberPulseDom",  0),
    ("OutputFirstguessName",   "OpheliaFirstGuess"),
    ("InputPulseName1",        "ATWDPortiaPulse"),
    ("InputPulseName2",        "FADCPortiaPulse"),
    ("InputLaunchName",        "CleanInIceRawData"),
    ("ChargeOption",           0),
    ("LCOption",               True)
    )

tray.AddModule("I3WeigherModuleJuliet","weight")(
    
    ("doTree",                 True),
    ("outFileName",            outrootfile2),
    ("inMCTreeName",           "I3MCTree"),
    ("inMCHitSeriesName",      "MCHitSeriesMap"),
    ("inDOMLaunchName",        "CleanInIceRawData"),
    
    ("doPulseTree",            False),
    ("inAtwdPortiaName",       "ATWDPortiaPulse"),
    ("inFadcPortiaName",       "FADCPortiaPulse"),
    
    ("doMCHitTree",            False),
    #  ("McHitCompressionOption", True),
    ("frameMCWeightName", "JulietWeightDict"),
    
    ("doFirstguessTree",       True),
    ("inFirstguessName",       "OpheliaFirstGuess"),
    
    ("doFillWeight",      False),
    ("doReWeigh",          False),
    )



#tray.AddModule("I3Writer","writer")(
#    ("filename",outfile),
#    ("skipkeys",["DOMLaunch"]),
#    ("streams",["Physics"])
#   )

tray.AddModule("TrashCan","trashcan")
    

tray.Execute()
tray.Finish()
    
